@@ -1,11 +1,12 @@
 #' Tally a Genomic Alteration Object
 #'
-#' Tally a variation object like [MAF] and return a matrix for NMF de-composition and more.
+#' Tally a variation object like [MAF], [CopyNumber] and return a matrix for NMF de-composition and more.
 #' This is a generic function,
 #' so it can be further extended to other mutation cases.
 #' Please read details about how to set sex for identifying copy number signatures.
 #' Please read <https://osf.io/s93d5/> for the generation of SBS, DBS and ID (INDEL)
-#' components.
+#' components. **Of note, many options are designed for method "M" only, and they are highlighted
+#' by bold fonts** (you can ignore them if you don't use "M" method).
 #'
 #' For identifying copy number signatures, we have to derive copy number
 #' features firstly. Due to the difference of copy number values in sex chromosomes
@@ -21,7 +22,7 @@
 #' - If your cohort are all males, set `sigminer.sex` to 'male' and
 #' `sigminer.copynumber.max` to a proper value (the best is consistent
 #' with [read_copynumber]).
-#' - If your cohort contains bother males and females, set `sigminer.sex`
+#' - If your cohort contains both males and females, set `sigminer.sex`
 #' as a `data.frame` with two columns "sample" and "sex". And
 #' set `sigminer.copynumber.max` to a proper value (the best is consistent
 #' with [read_copynumber]).
@@ -120,49 +121,53 @@ sig_tally <- function(object, ...) {
 }
 
 #' @describeIn sig_tally Returns copy number features, components and component-by-sample matrix
-#' @param method method for feature classfication, can be one of "Macintyre" ("M") and
-#' "Wang" ("W").
+#' @param method method for feature classfication, can be one of "Macintyre" ("M"),
+#' "Wang" ("W") and "Tao & Wang" ("T").
 #' @param feature_setting a `data.frame` used for classification.
-#' Only used when method is "Wang" ("W").
+#' **Only used when method is "Wang" ("W")**.
 #' Default is [CN.features]. Users can also set custom input with "feature",
 #' "min" and "max" columns available. Valid features can be printed by
 #' `unique(CN.features$feature)`.
 #' @param type one of "probability", "count". Default is "probability", return a matrix
 #' with the sum of posterior probabilities for each components. If set to 'count',
 #' return a matrix with event count assigned to each components. The result for
-#' both types should be close. Only used when method is "Macintyre".
+#' both types should be close. **Only used when method is "Macintyre"**.
 #' @param reference_components default is `FALSE`, calculate mixture components
-#' from [CopyNumber] object. Only used when method is "Macintyre".
-#' @param cores number of compute cores to run this task.
+#' from [CopyNumber] object. **Only used when method is "Macintyre"**.
+#' @param cores number of computer cores to run this task.
 #' You can use [future::availableCores()] function to check how
 #' many cores you can use.
-#' @param seed seed number. Only used when method is "Macintyre".
+#' @param seed seed number. **Only used when method is "Macintyre"**.
 #' @param min_comp minimal number of components to fit, default is 2.
 #' Can also be a vector with length 6, which apply to each feature.
-#' Only used when method is "Macintyre".
+#' **Only used when method is "Macintyre"**.
 #' @param max_comp maximal number of components to fit, default is 15.
 #' Can also be a vector with length 6, which apply to each feature.
-#' Only used when method is "Macintyre".
+#' **Only used when method is "Macintyre"**.
 #' @param min_prior the minimum relative size of components, default is 0.001.
 #' Details about custom setting please refer to **flexmix** package.
-#' Only used when method is "Macintyre".
+#' **Only used when method is "Macintyre"**.
 #' @param model_selection model selection strategy, default is 'BIC'.
 #' Details about custom setting please refer to **flexmix** package.
-#' Only used when method is "Macintyre".
+#' **Only used when method is "Macintyre"**.
 #' @param threshold default is `0.1`. Sometimes, the result components
 #' include adjacent distributions with similar mu
 #' (two and more distribution are very close), we use this threshold
 #' to obtain a more meaningful fit with less components.
-#' Only used when method is "Macintyre".
+#' **Only used when method is "Macintyre"**.
 #' @param nrep number of run times for each value of component,
 #' keep only the solution with maximum likelihood.
-#' Only used when method is "Macintyre".
+#' **Only used when method is "Macintyre"**.
 #' @param niter the maximum number of iterations.
-#' Only used when method is "Macintyre".
+#' **Only used when method is "Macintyre"**.
 #' @param keep_only_matrix if `TRUE`, keep only matrix for signature extraction.
 #' For a `MAF` object, this will just return the most useful matrix.
-#' @references Macintyre, Geoff, et al. "Copy number signatures and mutational
+#' @references
+#' Macintyre, Geoff, et al. "Copy number signatures and mutational
 #' processes in ovarian carcinoma." Nature genetics 50.9 (2018): 1262.
+#'
+#' Wang, Shixiang, et al. "Copy number signature analyses in prostate cancer reveal
+#' distinct etiologies and clinical outcomes." medRxiv (2020).
 #' @export
 sig_tally.CopyNumber <- function(object,
                                  method = "Wang",
@@ -179,9 +184,14 @@ sig_tally.CopyNumber <- function(object,
                                  keep_only_matrix = FALSE,
                                  ...) {
   stopifnot(is.logical(reference_components) | is.list(reference_components) | is.null(reference_components))
-  method <- match.arg(method, choices = c("Macintyre", "M", "Wang", "W"))
+  method <- match.arg(method, choices = c("Macintyre", "M", "Wang", "W", "Tao & Wang", "T"))
 
-  cn_list <- get_cnlist(object, ignore_chrs = ignore_chrs)
+  if (startsWith(method, "T")) {
+    ## Add segment index for method "T" so the segments can be easily joined or checked
+    cn_list <- get_cnlist(object, ignore_chrs = ignore_chrs, add_index = TRUE)
+  } else {
+    cn_list <- get_cnlist(object, ignore_chrs = ignore_chrs)
+  }
 
   if (startsWith(method, "M")) {
     if (!requireNamespace("flexmix", quietly = TRUE)) {
@@ -228,7 +238,7 @@ sig_tally.CopyNumber <- function(object,
         cores = cores
       )
     }
-  } else {
+  } else if (startsWith(method, "W")) {
     # Method: Wang Shixiang, 'W'
 
     send_info("Step: getting copy number features.")
@@ -275,6 +285,58 @@ sig_tally.CopyNumber <- function(object,
     }
     # cn_matrix[is.na(cn_matrix)] <- 0L
     feature_setting$n_obs <- colSums(cn_matrix, na.rm = TRUE)
+  } else {
+    # Method: Tao & Wang, 'T'
+
+    ## TODO: should also set a feature_setting dataset??
+    ## Is genome_build necessary here??
+    send_info("Step: getting copy number features.")
+    cn_features <- get_features_mutex(
+      CN_data = cn_list, cores = cores,
+      genome_build = object@genome_build,
+      feature_setting = feature_setting
+    )
+    send_success("Gotten.")
+
+    ## Curretly return features and explore how to combine them
+    return(cn_features)
+    # Make order as unique(feature_setting)$feature
+    # cn_features <- cn_features[unique(feature_setting$feature)]
+
+    # send_info("Step: generating copy number components based on combination.")
+    # # Check feature setting
+    # if (!inherits(feature_setting, "sigminer.features")) {
+    #   feature_setting <- get_feature_components(feature_setting)
+    # }
+    # send_success("{.code feature_setting} checked.")
+    #
+    # send_info("Step: counting components.")
+    # cn_components <- purrr::map2(cn_features, names(cn_features),
+    #                              count_components_wrapper,
+    #                              feature_setting = feature_setting
+    # )
+    # send_success("Counted.")
+    #
+    # ## Remove BoChr value is 0 in features
+    # if ("BoChr" %in% names(cn_features)) {
+    #   cn_features$BoChr <- cn_features$BoChr[cn_features$BoChr$value != 0]
+    # }
+    #
+    # send_info("Step: generating components by sample matrix.")
+    # cn_matrix <- data.table::rbindlist(cn_components, fill = TRUE, use.names = TRUE) %>%
+    #   dplyr::as_tibble() %>%
+    #   tibble::column_to_rownames(var = "component") %>%
+    #   as.matrix()
+    # # Order the matrix as feature_setting
+    # cn_matrix <- cn_matrix[feature_setting$component, ] %>%
+    #   t()
+    #
+    # if (any(is.na(cn_matrix))) {
+    #   send_warning("{.code NA} detected. There may be an issue, please contact the developer!")
+    #   send_warning("Data will still returned, but please take case of it.")
+    # }
+    # # cn_matrix[is.na(cn_matrix)] <- 0L
+    # feature_setting$n_obs <- colSums(cn_matrix, na.rm = TRUE)
   }
 
   send_success("Matrix generated.")
@@ -283,6 +345,9 @@ sig_tally.CopyNumber <- function(object,
     cn_matrix
   } else {
     if (startsWith(method, "M")) {
+      if (is.null(cn_components)) {
+        cn_components <- readRDS(file.path(tempdir(), "Nat_Gen_component_parameters.rds"))
+      }
       para_df <- get_tidy_parameter(cn_components)
     } else {
       para_df <- feature_setting
